"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./../../../../../shared/constants");
const logger_1 = __importDefault(require("../../../../../shared/logger"));
const run_multiple_command_1 = require("../../../../../shared/util/run-multiple-command");
const get_content_files_1 = require("../../../../../shared/util/get-content-files");
const get_repository_name_1 = require("../../../../../shared/util/get-repository-name");
const fs = require("fs");
exports.updateConfigContinuosIntegration = (directory) => {
    logger_1.default.info("Update continuos integration config");
    return Promise.all(directory.map((dir) => __awaiter(this, void 0, void 0, function* () {
        // 1. Elimino la carpeta config
        yield deletConfigFolder(dir);
        // 2. Creo la carpeta config
        yield createConfigFolder(dir);
        // 3. Creo el template de aws.
        yield createTemplateFiles(dir);
        // 4. Creo el archivo de sonar
        yield createSonarFiles(dir);
    })));
};
const createConfigFolder = (directory) => __awaiter(this, void 0, void 0, function* () {
    logger_1.default.debug("creating folder config.");
    return yield run_multiple_command_1.runMultipleCommand(`cd ${directory} && ${constants_1.consts.exito.command_generate_config}`);
});
const deletConfigFolder = (directory) => __awaiter(this, void 0, void 0, function* () {
    logger_1.default.debug("deleting current folder.");
    return yield deleteFolderRecursive(directory + "/config");
});
const createSonarFiles = (directory) => __awaiter(this, void 0, void 0, function* () {
    logger_1.default.debug("creating sonar configuration.");
    const repositoryName = yield get_repository_name_1.getRepositoryName(directory);
    const manifest = yield get_content_files_1.getManifestContent(directory);
    return yield run_multiple_command_1.runMultipleCommand(`cd ${directory} && ${constants_1.consts.exito.command_generate_sonar} ${repositoryName} ${manifest.version} ${constants_1.consts.exito.default_src}`);
});
const createTemplateFiles = (directory) => __awaiter(this, void 0, void 0, function* () {
    logger_1.default.debug("creating templates for aws.");
    const repositoryName = yield get_repository_name_1.getRepositoryName(directory);
    return yield run_multiple_command_1.runMultipleCommand(`cd ${directory} && ${constants_1.consts.exito.command_generate_tempalte} ${repositoryName}`);
});
// Método para eliminar la carpeta config
const deleteFolderRecursive = function (path) {
    if (fs.existsSync(path)) {
        fs.readdirSync(path).forEach(function (file) {
            const curPath = path + "/" + file;
            if (fs.lstatSync(curPath).isDirectory()) {
                // recurse
                deleteFolderRecursive(curPath);
            }
            else {
                // delete file
                fs.unlinkSync(curPath);
            }
        });
        fs.rmdirSync(path);
    }
};
