"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./../../../shared/constants");
const logger_1 = __importDefault(require("./../../../shared/logger"));
const read_directory_1 = require("../../../shared/util/read-directory");
const get_repository_name_1 = require("../../../shared/util/get-repository-name");
const get_template_1 = require("./util/get-template");
const dirname = process.cwd();
const { codeBuild, codePipeline, cloudFormationDir } = constants_1.consts.aws_template;
let fs = require("fs");
/**
 * Este archivo realiza la creación de la estructura base para el tema de la aplicación.
 * recibe como parametro el nombre del tema que se va a emplear
 *
 */
exports.default = (nameConfig, branchName, ymlDirectory) => __awaiter(this, void 0, void 0, function* () {
    logger_1.default.info("Creating aws cloud-formation template");
    logger_1.default.info(dirname);
    // 1. Leo el directorio actual y permito seleccionar todos los proyectos deseados
    const currentDirectory = yield read_directory_1.readDirectoryByFiles(dirname, [
        "manifest.json"
    ]);
    // 2. Obtengo los nombres de los proyectos. en base al nombre de la carpeta
    let repositoryNames = getProyectNames(currentDirectory);
    // 2. Armo el objeto que contendra los recursos de codecommit y codebuild. ademas de la información basica para el codepipeline
    // remuevo puntos del nombre ingresado, esto genera error en aws
    const nameRepositoryFormat = nameConfig.replace(".", "-");
    let config = {
        codeCommitProyects: repositoryNames,
        nameBranch: branchName,
        buildSpecDir: ymlDirectory,
        codeBuildName: `${nameRepositoryFormat}-${codeBuild}-${branchName}`,
        codePipeLineName: `${nameRepositoryFormat}-${codePipeline}-${branchName}`
    };
    createAwsTemplate(config);
});
// Método que recorre la lista de proyectos y obtiene el nombre a emplear de acuerdo a la carpeta.
const getProyectNames = (currentDirectory) => {
    let repositoryNames = [];
    currentDirectory.map((item) => __awaiter(this, void 0, void 0, function* () {
        repositoryNames.push(get_repository_name_1.getRepositoryName(item));
    }));
    return repositoryNames;
};
const createAwsTemplate = (config) => __awaiter(this, void 0, void 0, function* () {
    yield ensureDirectoryExistence(dirname);
    yield ensureDirectoryExistence(dirname + `/${cloudFormationDir}`);
    yield createTemplate(config);
});
const ensureDirectoryExistence = (filePath) => __awaiter(this, void 0, void 0, function* () {
    if (fs.existsSync(filePath)) {
        return true;
    }
    yield fs.mkdirSync(filePath);
    return true;
});
/**
 * Método que sobreescribe el archivo de tema base para la aplicación.
 */
const createTemplate = (options) => __awaiter(this, void 0, void 0, function* () {
    return fs.writeFile(`${dirname}/${cloudFormationDir}/${options.nameBranch}.json`, yield get_template_1.getTemplateContent(options), function (err) {
        if (err) {
            throw err;
        }
    });
});
