"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./../../../shared/constants");
const logger_1 = __importDefault(require("./../../../shared/logger"));
const get_template_1 = require("./util/get-template");
let fs = require('fs');
const { configDir, cloudFormationDir, themeDevelop, themeMaster, buildSpecDevelopDir, buildSpecMasterDir, codeBuild, codePipeline, branchDevelop, branchMaster } = constants_1.consts.aws_template;
const dirname = process.cwd() + `/${configDir}`;
/**
 * Este archivo realiza la creación de la estructura base para el tema de la aplicación.
 * recibe como parametro el nombre del tema que se va a emplear
 *
 */
exports.default = (repository) => __awaiter(this, void 0, void 0, function* () {
    logger_1.default.info('Creating aws cloud-formation template');
    const nameRepositoryFormat = repository.replace('.', '-');
    let config = {
        nameRepository: repository,
        nameBranch: branchDevelop,
        namefile: themeDevelop,
        buildSpecDir: buildSpecDevelopDir,
        codeBuildName: `${nameRepositoryFormat}-${codeBuild}-${branchDevelop}`,
        codePipeLineName: `${nameRepositoryFormat}-${codePipeline}-${branchDevelop}`
    };
    yield ensureDirectoryExistence(dirname);
    yield ensureDirectoryExistence(dirname + `/${cloudFormationDir}`);
    logger_1.default.info('Creating develop template');
    yield createTemplate(config);
    logger_1.default.info('Creating master template');
    config = {
        nameRepository: repository,
        nameBranch: branchMaster,
        namefile: themeMaster,
        buildSpecDir: buildSpecMasterDir,
        codeBuildName: `${nameRepositoryFormat}-${codeBuild}-${branchMaster}`,
        codePipeLineName: `${nameRepositoryFormat}-${codePipeline}-${branchMaster}`
    };
    yield createTemplate(config);
    logger_1.default.info('Templates generate succesfully!!');
});
const ensureDirectoryExistence = (filePath) => __awaiter(this, void 0, void 0, function* () {
    if (fs.existsSync(filePath)) {
        return true;
    }
    yield fs.mkdirSync(filePath);
    return true;
});
/**
 * Método que sobreescribe el archivo de tema base para la aplicación.
 */
const createTemplate = (options) => __awaiter(this, void 0, void 0, function* () {
    return fs.writeFile(`${dirname}/${cloudFormationDir}/${options.namefile}.json`, yield get_template_1.getTemplateContent(options), function (err) {
        if (err) {
            throw err;
        }
    });
});
