"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = __importDefault(require("./../../../../shared/logger"));
const config_template_1 = require("./util/config-template");
const run_only_command_1 = require("../../../../shared/util/run-only-command");
const axios_1 = __importDefault(require("axios"));
let fs = require('fs');
const chalk_1 = __importDefault(require("chalk"));
const ora_1 = __importDefault(require("ora"));
// Call to get auth information
const getAuth = (workspace, account) => __awaiter(this, void 0, void 0, function* () {
    try {
        logger_1.default.debug(`https://${workspace}--${account}.myvtex.com/exito/token?config=${makeid()}`);
        return yield axios_1.default.get(`https://${workspace}--${account}.myvtex.com/exito/token?config=${makeid()}`);
    }
    catch (error) {
        logger_1.default.debug(error);
        logger_1.default.error('Error on get auth token');
        process.exit(1);
    }
});
function makeid() {
    var text = '';
    var possible = 'abcdefghijklmnopqrstuvwxyz';
    for (var i = 0; i < 5; i++)
        text += possible.charAt(Math.floor(Math.random() * possible.length));
    return text;
}
function default_1(account, workspace, email) {
    return __awaiter(this, void 0, void 0, function* () {
        const spinner = ora_1.default('Getting auth token \n').start();
        spinner.stop();
        const auth = yield getAuth(workspace, account);
        spinner.start();
        if (auth) {
            const authToken = auth.data;
            // print information
            spinner.succeed(`auth token to use: ${chalk_1.default.redBright(authToken.slice(1, 20))}...`);
            logger_1.default.info(`Credentials for use ${chalk_1.default.redBright(account)} as ${chalk_1.default.redBright(email)} at workspace ${chalk_1.default.redBright(workspace)}`);
            // 1. Find the directory of the file for config vtex
            const vtexDirConfig = yield run_only_command_1.runOnlyCommand('find  ~/.config/configstore/vtex.json');
            if (!vtexDirConfig) {
                logger_1.default.error('Error on fin the config file of vtex');
            }
            else {
                // print the current ubication from the file config vtex.json
                logger_1.default.debug(`vtex.json ubication: ${chalk_1.default.redBright(vtexDirConfig.replace(/\s/g, ''))}`);
                // options for the file config.json
                const options = {
                    account: account,
                    authToken: authToken,
                    workspase: workspace,
                    login: email
                };
                // 2. Overrite the config file from vtex
                yield overwriteFile(vtexDirConfig, options);
                spinner.succeed(`Now you logged in Vtex!!`);
            }
        }
        else {
            spinner.fail('No token information found.');
            process.exit(1);
        }
    });
}
exports.default = default_1;
/**
 * Método que sobreescribe el archivo de tema base para la aplicación.
 */
const overwriteFile = (dirname, options) => __awaiter(this, void 0, void 0, function* () {
    try {
        // remove white spaces in the path
        return fs.writeFile(`${dirname.replace(/\s/g, '')}`, yield config_template_1.getConfigTemplate(options), function (err) {
            if (err) {
                throw err;
            }
        });
    }
    catch (error) {
        logger_1.default.debug('error' + error);
    }
});
